@@ -11,13 +11,13 @@ RSpec.describe "ruby requirement" do
   it "allows adding gems" do
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby "#{RUBY_VERSION}"
+      ruby "#{Gem.ruby_version}"
       gem "rack"
     G
 
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby "#{RUBY_VERSION}"
+      ruby "#{Gem.ruby_version}"
       gem "rack"
       gem "rack-obama"
     G
@@ -28,7 +28,7 @@ RSpec.describe "ruby requirement" do
   it "allows removing the ruby version requirement" do
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby "~> #{RUBY_VERSION}"
+      ruby "~> #{Gem.ruby_version}"
       gem "rack"
     G
 
@@ -46,7 +46,7 @@ RSpec.describe "ruby requirement" do
   it "allows changing the ruby version requirement to something compatible" do
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby ">= #{RUBY_VERSION[0..2]}.0"
+      ruby ">= #{current_ruby_minor}"
       gem "rack"
     G
 
@@ -55,7 +55,7 @@ RSpec.describe "ruby requirement" do
 
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby ">= #{RUBY_VERSION}"
+      ruby ">= #{Gem.ruby_version}"
       gem "rack"
     G
 
@@ -93,7 +93,7 @@ RSpec.describe "ruby requirement" do
 
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby ">= #{RUBY_VERSION[0..2]}.0"
+      ruby ">= #{current_ruby_minor}"
       gem "rack"
     G
 
@@ -104,7 +104,7 @@ RSpec.describe "ruby requirement" do
   it "allows requirements with trailing whitespace" do
     install_gemfile <<-G
       source "#{file_uri_for(gem_repo1)}"
-      ruby "#{RUBY_VERSION}\\n \t\\n"
+      ruby "#{Gem.ruby_version}\\n \t\\n"
       gem "rack"
     G
 
@@ -112,7 +112,7 @@ RSpec.describe "ruby requirement" do
   end
 
   it "fails gracefully with malformed requirements" do
-    install_gemfile <<-G, :raise_on_error => false
+    install_gemfile <<-G, raise_on_error: false
       source "#{file_uri_for(gem_repo1)}"
       ruby ">= 0", "-.\\0"
       gem "rack"
@@ -120,4 +120,38 @@ RSpec.describe "ruby requirement" do
 
     expect(err).to include("There was an error parsing") # i.e. DSL error, not error template
   end
+
+  it "allows picking up ruby version from a file" do
+    create_file ".ruby-version", Gem.ruby_version.to_s
+
+    install_gemfile <<-G
+      source "#{file_uri_for(gem_repo1)}"
+      ruby file: ".ruby-version"
+      gem "rack"
+    G
+
+    expect(lockfile).to include("RUBY VERSION")
+  end
+
+  it "reads the ruby version file from the right folder when nested Gemfiles are involved" do
+    create_file ".ruby-version", Gem.ruby_version.to_s
+
+    gemfile <<-G
+      source "#{file_uri_for(gem_repo1)}"
+      ruby file: ".ruby-version"
+      gem "rack"
+    G
+
+    nested_dir = bundled_app(".ruby-lsp")
+
+    FileUtils.mkdir nested_dir
+
+    create_file ".ruby-lsp/Gemfile", <<-G
+      eval_gemfile(File.expand_path("../Gemfile", __dir__))
+    G
+
+    bundle "install", dir: nested_dir
+
+    expect(bundled_app(".ruby-lsp/Gemfile.lock").read).to include("RUBY VERSION")
+  end
 end
