@@ -4,7 +4,7 @@ RSpec.describe "bundle install" do
   describe "when a gem has a YAML gemspec" do
     before :each do
       build_repo2 do
-        build_gem "yaml_spec", :gemspec => :yaml
+        build_gem "yaml_spec", gemspec: :yaml
       end
     end
 
@@ -18,9 +18,10 @@ RSpec.describe "bundle install" do
     end
 
     it "still installs correctly when using path" do
-      build_lib "yaml_spec", :gemspec => :yaml
+      build_lib "yaml_spec", gemspec: :yaml
 
       install_gemfile <<-G
+        source "#{file_uri_for(gem_repo1)}"
         gem 'yaml_spec', :path => "#{lib_path("yaml_spec-1.0")}"
       G
       expect(err).to be_empty
@@ -33,6 +34,8 @@ RSpec.describe "bundle install" do
       gem 'rack'
     G
 
+    system_gems "rack-1.0.0", path: default_bundle_path
+
     FileUtils.mkdir_p "#{default_bundle_path}/specifications"
     File.open("#{default_bundle_path}/specifications/rack-1.0.0.gemspec", "w+") do |f|
       spec = Gem::Specification.new do |s|
@@ -42,8 +45,8 @@ RSpec.describe "bundle install" do
       end
       f.write spec.to_ruby
     end
-    bundle :install, :artifice => "endpoint_marshal_fail" # force gemspec load
-    expect(the_bundle).to include_gems "activesupport 2.3.2"
+    bundle :install, artifice: "endpoint_marshal_fail" # force gemspec load
+    expect(the_bundle).to include_gems "rack 1.0.0", "activesupport 2.3.2"
   end
 
   it "does not hang when gemspec has incompatible encoding" do
@@ -56,7 +59,8 @@ RSpec.describe "bundle install" do
       end
     G
 
-    install_gemfile <<-G, :env => { "LANG" => "C" }
+    install_gemfile <<-G, env: { "LANG" => "C" }
+      source "#{file_uri_for(gem_repo1)}"
       gemspec
     G
 
@@ -82,6 +86,7 @@ RSpec.describe "bundle install" do
     G
 
     install_gemfile <<-G
+      source "#{file_uri_for(gem_repo1)}"
       gemspec
     G
 
@@ -89,40 +94,44 @@ RSpec.describe "bundle install" do
   end
 
   context "when ruby version is specified in gemspec and gemfile" do
-    it "installs when patch level is not specified and the version matches" do
-      build_lib("foo", :path => bundled_app) do |s|
+    it "installs when patch level is not specified and the version matches",
+      if: RUBY_PATCHLEVEL >= 0 do
+      build_lib("foo", path: bundled_app) do |s|
         s.required_ruby_version = "~> #{RUBY_VERSION}.0"
       end
 
       install_gemfile <<-G
         ruby '#{RUBY_VERSION}', :engine_version => '#{RUBY_VERSION}', :engine => 'ruby'
+        source "#{file_uri_for(gem_repo1)}"
         gemspec
       G
       expect(the_bundle).to include_gems "foo 1.0"
     end
 
     it "installs when patch level is specified and the version still matches the current version",
-      :if => RUBY_PATCHLEVEL >= 0 do
-      build_lib("foo", :path => bundled_app) do |s|
+      if: RUBY_PATCHLEVEL >= 0 do
+      build_lib("foo", path: bundled_app) do |s|
         s.required_ruby_version = "#{RUBY_VERSION}.#{RUBY_PATCHLEVEL}"
       end
 
-      install_gemfile <<-G, :raise_on_error => false
+      install_gemfile <<-G, raise_on_error: false
         ruby '#{RUBY_VERSION}', :engine_version => '#{RUBY_VERSION}', :engine => 'ruby', :patchlevel => '#{RUBY_PATCHLEVEL}'
+        source "#{file_uri_for(gem_repo1)}"
         gemspec
       G
       expect(the_bundle).to include_gems "foo 1.0"
     end
 
     it "fails and complains about patchlevel on patchlevel mismatch",
-      :if => RUBY_PATCHLEVEL >= 0 do
+      if: RUBY_PATCHLEVEL >= 0 do
       patchlevel = RUBY_PATCHLEVEL.to_i + 1
-      build_lib("foo", :path => bundled_app) do |s|
+      build_lib("foo", path: bundled_app) do |s|
         s.required_ruby_version = "#{RUBY_VERSION}.#{patchlevel}"
       end
 
-      install_gemfile <<-G, :raise_on_error => false
+      install_gemfile <<-G, raise_on_error: false
         ruby '#{RUBY_VERSION}', :engine_version => '#{RUBY_VERSION}', :engine => 'ruby', :patchlevel => '#{patchlevel}'
+        source "#{file_uri_for(gem_repo1)}"
         gemspec
       G
 
@@ -134,12 +143,13 @@ RSpec.describe "bundle install" do
     it "fails and complains about version on version mismatch" do
       version = Gem::Requirement.create(RUBY_VERSION).requirements.first.last.bump.version
 
-      build_lib("foo", :path => bundled_app) do |s|
+      build_lib("foo", path: bundled_app) do |s|
         s.required_ruby_version = version
       end
 
-      install_gemfile <<-G, :raise_on_error => false
+      install_gemfile <<-G, raise_on_error: false
         ruby '#{version}', :engine_version => '#{version}', :engine => 'ruby'
+        source "#{file_uri_for(gem_repo1)}"
         gemspec
       G
 
