@@ -1,4 +1,4 @@
-require File.expand_path('../../../spec_helper', __FILE__)
+require_relative '../../spec_helper'
 require 'bigdecimal'
 
 describe "BigDecimal#+@" do
@@ -15,6 +15,3 @@ describe "BigDecimal#+@" do
     fifth.send(:+@).should == fifth
   end
 end
-
-
-
