@@ -1,4 +1,4 @@
-require File.expand_path('../../../spec_helper', __FILE__)
+require_relative '../../spec_helper'
 require 'date'
 
 describe "DateTime.new" do
@@ -47,6 +47,6 @@ describe "DateTime.new" do
   end
 
   it "raises an error on invalid arguments" do
-    lambda { new_datetime(minute: 999) }.should raise_error(ArgumentError)
+    -> { new_datetime(minute: 999) }.should raise_error(ArgumentError)
   end
 end
