@@ -92,12 +92,10 @@ class TestGemRequire < Gem::TestCase
 
   def create_sync_thread
     Thread.new do
-      begin
-        yield
-      ensure
-        FILE_ENTERED_LATCH.release
-        FILE_EXIT_LATCH.await
-      end
+      yield
+    ensure
+      FILE_ENTERED_LATCH.release
+      FILE_EXIT_LATCH.await
     end
   end
 
@@ -227,7 +225,7 @@ class TestGemRequire < Gem::TestCase
     pend "Not sure what's going on. If another spec creates a 'a' gem before
       this test, somehow require will load the benchmark in b, and ignore that the
       stdlib one is already in $LOADED_FEATURES?. Reproducible by running the
-      spaceship_specific_file test before this one" if java_platform?
+      spaceship_specific_file test before this one" if Gem.java_platform?
 
     pend "not installed yet" unless RbConfig::TOPDIR
 
@@ -384,8 +382,8 @@ class TestGemRequire < Gem::TestCase
 
     # Remove an old default gem version directly from disk as if someone ran
     # gem cleanup.
-    FileUtils.rm_rf(File.join @gemhome, "#{b1.full_name}")
-    FileUtils.rm_rf(File.join @gemhome, "specifications", "default", "#{b1.full_name}.gemspec")
+    FileUtils.rm_rf(File.join(@gemhome, b1.full_name.to_s))
+    FileUtils.rm_rf(File.join(@gemhome, "specifications", "default", "#{b1.full_name}.gemspec"))
 
     # Require gems that have not been removed.
     assert_require "a/b"
@@ -426,7 +424,7 @@ class TestGemRequire < Gem::TestCase
 
     times_called = 0
 
-    Kernel.stub(:gem, ->(name, requirement) { times_called += 1 }) do
+    Kernel.stub(:gem, ->(_name, _requirement) { times_called += 1 }) do
       refute_require "default/gem"
     end
 
@@ -473,11 +471,11 @@ class TestGemRequire < Gem::TestCase
     File.write(path, code)
 
     output = Gem::Util.popen({ "GEM_HOME" => @gemhome }, *ruby_with_rubygems_in_load_path, path).strip
-    assert $?.success?
     refute_empty output
     assert_equal "999.99.9", output.lines[0].chomp
     # Make sure only files from the newer json gem are loaded, and no files from the default json gem
     assert_equal ["#{@gemhome}/gems/json-999.99.9/lib/json.rb"], output.lines.grep(%r{/gems/json-}).map(&:chomp)
+    assert $?.success?
   end
 
   def test_default_gem_and_normal_gem
@@ -491,6 +489,17 @@ class TestGemRequire < Gem::TestCase
     assert_equal %w[default-3.0], loaded_spec_names
   end
 
+  def test_normal_gem_does_not_shadow_default_gem
+    default_gem_spec = new_default_spec("foo", "2.0", nil, "foo.rb")
+    install_default_gems(default_gem_spec)
+
+    normal_gem_spec = util_spec("fake-foo", "3.0", nil, "lib/foo.rb")
+    install_specs(normal_gem_spec)
+
+    assert_require "foo"
+    assert_equal %w[foo-2.0], loaded_spec_names
+  end
+
   def test_normal_gems_with_overridden_load_error_message
     normal_gem_spec = util_spec("normal", "3.0", nil, "lib/normal/gem.rb")
 
@@ -531,6 +540,65 @@ class TestGemRequire < Gem::TestCase
     assert_equal %w[default-3.0.0.rc2], loaded_spec_names
   end
 
+  def test_default_gem_with_unresolved_gems_depending_on_it
+    my_http_old = util_spec "my-http", "0.1.1", nil, "lib/my/http.rb"
+    install_gem my_http_old
+
+    my_http_default = new_default_spec "my-http", "0.3.0", nil, "my/http.rb"
+    install_default_gems my_http_default
+
+    faraday_1 = util_spec "faraday", "1", { "my-http" => ">= 0" }
+    install_gem faraday_1
+
+    faraday_2 = util_spec "faraday", "2", { "my-http" => ">= 0" }
+    install_gem faraday_2
+
+    chef = util_spec "chef", "1", { "faraday" => [">= 1", "< 3"] }, "lib/chef.rb"
+    install_gem chef
+
+    assert_require "chef"
+    assert_require "my/http"
+  end
+
+  def test_default_gem_required_circulary_with_unresolved_gems_depending_on_it
+    my_http_old = util_spec "my-http", "0.1.1", nil, "lib/my/http.rb"
+    install_gem my_http_old
+
+    my_http_default = new_default_spec "my-http", "0.3.0", nil, "my/http.rb"
+    my_http_default_path = File.join(@tempdir, "default_gems", "lib", "my/http.rb")
+    install_default_gems my_http_default
+    File.write(my_http_default_path, 'require "my/http"')
+
+    faraday_1 = util_spec "faraday", "1", { "my-http" => ">= 0" }
+    install_gem faraday_1
+
+    faraday_2 = util_spec "faraday", "2", { "my-http" => ">= 0" }
+    install_gem faraday_2
+
+    chef = util_spec "chef", "1", { "faraday" => [">= 1", "< 3"] }, "lib/chef.rb"
+    install_gem chef
+
+    assert_require "chef"
+
+    out, err = capture_output do
+      assert_require "my/http"
+    end
+
+    assert_empty out
+
+    circular_require_warning = false
+
+    err_lines = err.split("\n").reject do |line|
+      if line.include?("circular require")
+        circular_require_warning = true
+      elsif circular_require_warning # ignore backtrace lines for circular require warning
+        circular_require_warning = line.start_with?(/[\s]/)
+      end
+    end
+
+    assert_empty err_lines
+  end
+
   def loaded_spec_names
     Gem.loaded_specs.values.map(&:full_name).sort
   end
@@ -542,8 +610,10 @@ class TestGemRequire < Gem::TestCase
   def test_try_activate_error_unlocks_require_monitor
     silence_warnings do
       class << ::Gem
-        alias old_try_activate try_activate
-        def try_activate(*); raise "raised from try_activate"; end
+        alias_method :old_try_activate, :try_activate
+        def try_activate(*)
+          raise "raised from try_activate"
+        end
       end
     end
 
@@ -554,7 +624,7 @@ class TestGemRequire < Gem::TestCase
   ensure
     silence_warnings do
       class << ::Gem
-        alias try_activate old_try_activate
+        alias_method :try_activate, :old_try_activate
       end
     end
     Kernel::RUBYGEMS_ACTIVATION_MONITOR.exit
