@@ -13,7 +13,7 @@
 #include "ruby/ruby.h"
 #include "version.h"
 #include "vm_core.h"
-#include "mjit.h"
+#include "rjit.h"
 #include "yjit.h"
 #include <stdio.h>
 
@@ -39,11 +39,6 @@
 # define RUBY_RELEASE_DATETIME RUBY_RELEASE_DATE
 #endif
 
-# define RUBY_DESCRIPTION_WITH(opt) \
-    "ruby " RUBY_VERSION RUBY_PATCHLEVEL_STR " " \
-    "(" RUBY_RELEASE_DATETIME RUBY_REVISION_STR ")" opt " " \
-    "[" RUBY_PLATFORM "]"
-
 #define PRINT(type) puts(ruby_##type)
 #define MKSTR(type) rb_obj_freeze(rb_usascii_str_new_static(ruby_##type, sizeof(ruby_##type)-1))
 #define MKINT(name) INT2FIX(ruby_##name)
@@ -70,9 +65,13 @@ const char ruby_revision[] = RUBY_FULL_REVISION;
 const char ruby_release_date[] = RUBY_RELEASE_DATE;
 const char ruby_platform[] = RUBY_PLATFORM;
 const int ruby_patchlevel = RUBY_PATCHLEVEL;
-const char ruby_description[] = RUBY_DESCRIPTION_WITH("");
-static const char ruby_description_with_mjit[] = RUBY_DESCRIPTION_WITH(" +MJIT");
-static const char ruby_description_with_yjit[] = RUBY_DESCRIPTION_WITH(YJIT_DESCRIPTION);
+const char ruby_description[] =
+    "ruby " RUBY_VERSION RUBY_PATCHLEVEL_STR " "
+    "(" RUBY_RELEASE_DATETIME RUBY_REVISION_STR ") "
+    "[" RUBY_PLATFORM "]";
+static const int ruby_description_opt_point =
+    (int)(sizeof(ruby_description) - sizeof(" [" RUBY_PLATFORM "]"));
+
 const char ruby_copyright[] = "ruby - Copyright (C) "
     RUBY_BIRTH_YEAR_STR "-" RUBY_RELEASE_YEAR_STR " "
     RUBY_AUTHOR;
@@ -86,12 +85,14 @@ void
 Init_version(void)
 {
     enum {ruby_patchlevel = RUBY_PATCHLEVEL};
-    VALUE version;
-    VALUE ruby_engine_name;
+    VALUE version = MKSTR(version);
+    VALUE ruby_engine_name = MKSTR(engine);
+    // MKSTR macro is a marker for fake.rb
+
     /*
      * The running version of ruby
      */
-    rb_define_global_const("RUBY_VERSION", (version = MKSTR(version)));
+    rb_define_global_const("RUBY_VERSION", /* MKSTR(version) */ version);
     /*
      * The date this ruby was released
      */
@@ -116,20 +117,20 @@ Init_version(void)
     /*
      * The engine or interpreter this ruby uses.
      */
-    rb_define_global_const("RUBY_ENGINE", ruby_engine_name = MKSTR(engine));
+    rb_define_global_const("RUBY_ENGINE", /* MKSTR(engine) */ ruby_engine_name);
     ruby_set_script_name(ruby_engine_name);
     /*
      * The version of the engine or interpreter this ruby uses.
      */
-    rb_define_global_const("RUBY_ENGINE_VERSION", (1 ? version : MKSTR(version)));
+    rb_define_global_const("RUBY_ENGINE_VERSION", /* MKSTR(version) */ version);
 
     rb_provide("ruby2_keywords.rb");
 }
 
-#if USE_MJIT
-#define MJIT_OPTS_ON opt->mjit.on
+#if USE_RJIT
+#define RJIT_OPTS_ON opt->rjit.on
 #else
-#define MJIT_OPTS_ON 0
+#define RJIT_OPTS_ON 0
 #endif
 
 #if USE_YJIT
@@ -138,22 +139,36 @@ Init_version(void)
 #define YJIT_OPTS_ON 0
 #endif
 
-void
-Init_ruby_description(ruby_cmdline_options_t *opt)
-{
-    VALUE description;
+int ruby_mn_threads_enabled;
 
-    if (MJIT_OPTS_ON) {
-        rb_dynamic_description = ruby_description_with_mjit;
-        description = MKSTR(description_with_mjit);
-    }
-    else if (YJIT_OPTS_ON) {
-        rb_dynamic_description = ruby_description_with_yjit;
-        description = MKSTR(description_with_yjit);
-    }
-    else {
-        description = MKSTR(description);
-    }
+bool * rb_ruby_prism_ptr(void);
+
+static void
+define_ruby_description(const char *const jit_opt)
+{
+    static char desc[
+        sizeof(ruby_description)
+        + rb_strlen_lit(YJIT_DESCRIPTION)
+        + rb_strlen_lit(" +MN")
+        ];
+
+    const char *const threads_opt = ruby_mn_threads_enabled ? " +MN" : "";
+    const char *const parser_opt = (*rb_ruby_prism_ptr()) ? " +PRISM" : "";
+
+    int n = snprintf(desc, sizeof(desc),
+                     "%.*s"
+                     "%s" // jit_opt
+                     "%s" // threads_opts
+                     "%s" // parser_opt
+                     "%s",
+                     ruby_description_opt_point, ruby_description,
+                     jit_opt,
+                     threads_opt,
+                     parser_opt,
+                     ruby_description + ruby_description_opt_point);
+
+    VALUE description = rb_obj_freeze(rb_usascii_str_new_static(desc, n));
+    rb_dynamic_description = desc;
 
     /*
      * The full ruby version string, like <tt>ruby -v</tt> prints
@@ -161,6 +176,23 @@ Init_ruby_description(ruby_cmdline_options_t *opt)
     rb_define_global_const("RUBY_DESCRIPTION", /* MKSTR(description) */ description);
 }
 
+void
+Init_ruby_description(ruby_cmdline_options_t *opt)
+{
+    const char *const jit_opt =
+        RJIT_OPTS_ON ? " +RJIT" :
+        YJIT_OPTS_ON ? YJIT_DESCRIPTION :
+        "";
+    define_ruby_description(jit_opt);
+}
+
+void
+ruby_set_yjit_description(void)
+{
+    rb_const_remove(rb_cObject, rb_intern("RUBY_DESCRIPTION"));
+    define_ruby_description(YJIT_DESCRIPTION);
+}
+
 void
 ruby_show_version(void)
 {
